require 'spec_helper'

describe OmniAuth::Strategies::Learn do

  let(:access_token) { stub('AccessToken', :options => {}) }
  let(:parsed_response) { stub('ParsedResponse') }
  let(:response) { stub('Response', :parsed => parsed_response) }

  let(:learn_site)          { 'https://learn.co' }
  let(:learn_authorize_url) { 'https://learn.co/oauth/authorize' }
  let(:learn_token_url)     { 'https://learn.co/oauth/token' }
  let(:learn_authorizer) do
    OmniAuth::Strategies::Learn.new(ENV['LEARN_KEY'], ENV['LEARN_SECRET'])
  end

  let(:custom_learn_authorizer) do 
    OmniAuth::Strategies::Learn.new(ENV['LEARN_KEY'], ENV['LEARN_SECRET'],
        {
            :client_options => {
                :site => "http://localhost:3000",
                :authorize_url => "http://localhost:3000/oauth/authorize",
                :token_url => "http://localhost:3000/oauth/token"
            }
        }
    )
  end

  context "client options" do
    it 'has the correct authorize_url' do
      expect(learn_authorizer.client.options[:authorize_url]).to eq(learn_authorize_url)
    end

    it 'has the correct token_url' do 
      expect(learn_authorizer.client.options[:token_url]).to eq(learn_token_url)
    end

    describe "should be overrideable" do
      it "for authorize url" do
        expect(custom_learn_authorizer.client.options[:authorize_url]).to eq("http://localhost:3000/oauth/authorize")
      end

      it "for token url" do
        expect(custom_learn_authorizer.client.options[:token_url]).to eq("http://localhost:3000/oauth/token")
      end
    end
  end

  context "raw info" do 

    before(:each) do 
      learn_authorizer.stub(:access_token).and_return(access_token)
      allow(learn_authorizer.access_token).to receive(:get).and_return(parsed_response)
      res = learn_authorizer.access_token.get("/api/v1/users/me")
      allow(res).to receive(:parsed).and_return(parsed_response)
    end

    it "should be set equal to the response that the access token fetches from the Learn API" do
      expect(learn_authorizer.raw_info).to eq(parsed_response)
    end

    context "info" do 
      before do
        allow(learn_authorizer).to receive(:raw_info).and_return({"email" => "sophie@email.com"})
        allow(learn_authorizer.access_token).to receive(:token).and_return("testToken")
        allow(learn_authorizer.raw_info).to receive(:merge).and_return({"email" => "sophie@email.com", "token" => "testToken"})
      end

      it "constructs the info hash from the raw_info hash and the access token" do 
        expect(learn_authorizer.info).to eq({"email" => "sophie@email.com", "token" => "testToken"})
      end
    end
  end
end
